Documentation
¶
Overview ¶
loadmanager.go
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AdjustConcurrency ¶
func AdjustConcurrency(maxConcurrency int, loadThreshold float64) (int, float64, float64, float64, float64)
AdjustConcurrency adjusts concurrency based on load in the background and returns the calculated loads in the last 1, 5, and 15 minutes.
func CalculateLoad ¶
func CalculateLoad() float64
CalculateLoad calculates the combined CPU and memory load.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.